@@ -5,7 +5,9 @@ CrossValidationSSN <- function(object)
   V <- object$estimates$V
   Vi <- object$estimates$Vi
   n <- object$sampinfo$obs.sample.size
-	cdd.out <- matrix(-999.9, nrow = n, ncol = 2)
+  cdd.out <- matrix(-999.9, nrow = n, ncol = 3)
+  cdd.out[,1] <- attributes(object$sampinfo$z)$pid
+
 	for(i in 1:n) {
 		Vi.i <- Vi[(1:n) != i,(1:n) != i] -
 			matrix(Vi[(1:n) != i,i],ncol = 1) %*%
@@ -18,11 +20,13 @@ CrossValidationSSN <- function(object)
 		covb.i <- solve(t(X.i) %*% Vi.i %*% X.i)
 		si <- V[i,i]  - t(c.i) %*% Vi.i %*% c.i
 		lam <- t(c.i + X.i %*% covb.i %*% xxi) %*% Vi.i
-		cdd.out[i,1] <- lam %*% z.i
-		cdd.out[i,2] <- sqrt(si + t(xxi) %*% covb.i %*% xxi)
+
+		cdd.out[i,2] <- lam %*% z.i
+		cdd.out[i,3] <- sqrt(si + t(xxi) %*% covb.i %*% xxi)
+
 	}
 	cdd.out <- as.data.frame(cdd.out)
-	names(cdd.out) <- c("cv.pred","cv.se")
+	names(cdd.out) <- c("pid","cv.pred","cv.se")
 	cdd.out
 }
 
